# [Zope-tests] OK : Zope-2.13 Python-2.6.5 : Linux

Zope Tests zope-tests at epy.co.at
Wed Feb 2 01:15:00 EST 2011

- Previous message: [Zope-tests] OK : Zope-2.12-alltests Python-2.6.5 : Linux
- Next message: [Zope-tests] OK : Zope-2.13-alltests Python-2.6.5 : Linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    Zope Tests : OK
    Zope-2.13 Python-2.6.5 : Linux (x86_64)

    Running ./bin/test --all
    Running OFS.tests.testCopySupportEvents.EventLayer tests:
      Set up OFS.tests.testCopySupportEvents.EventLayer in 0.092 seconds.
      Ran 14 tests with 0 failures and 0 errors in 0.041 seconds.
    Running OFS.tests.testCopySupportHooks.HookLayer tests:
      Tear down OFS.tests.testCopySupportEvents.EventLayer in 0.000 seconds.
      Set up OFS.tests.testCopySupportHooks.HookLayer in 0.091 seconds.
      Ran 14 tests with 0 failures and 0 errors in 0.042 seconds.
    Running Testing.ZopeTestCase.layer.ZopeLite tests:
      Tear down OFS.tests.testCopySupportHooks.HookLayer in 0.000 seconds.
      Set up Testing.ZopeTestCase.layer.ZopeLite in 0.000 seconds.
      Ran 220 tests with 0 failures and 0 errors in 4.381 seconds.
    Running Testing.ZopeTestCase.testZODBCompat.ZODBCompatLayer tests:
      Set up Testing.ZopeTestCase.testZODBCompat.ZODBCompatLayer in 0.001 seconds.
      Ran 18 tests with 0 failures and 0 errors in 0.028 seconds.
    Running Testing.ZopeTestCase.zopedoctest.testLayerExtraction.TestLayer tests:
      Tear down Testing.ZopeTestCase.testZODBCompat.ZODBCompatLayer in 0.001 seconds.
      Set up Testing.ZopeTestCase.zopedoctest.testLayerExtraction.TestLayer in 0.001 seconds.
      Ran 2 tests with 0 failures and 0 errors in 0.004 seconds.
    Running zope.testing.testrunner.layer.UnitTests tests:
      Tear down Testing.ZopeTestCase.zopedoctest.testLayerExtraction.TestLayer in 0.001 seconds.
      Tear down Testing.ZopeTestCase.layer.ZopeLite in 0.000 seconds.
      Set up zope.testing.testrunner.layer.UnitTests in 0.000 seconds.
      Ran 1231 tests with 0 failures and 0 errors in 27.764 seconds.
    Tearing down left over layers:
      Tear down zope.testing.testrunner.layer.UnitTests in 0.000 seconds.
    Total: 1499 tests, 0 failures, 0 errors in 33.038 seconds.

    OK

- Previous message: [Zope-tests] OK : Zope-2.12-alltests Python-2.6.5 : Linux
- Next message: [Zope-tests] OK : Zope-2.13-alltests Python-2.6.5 : Linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list